---
name: Feature request
about: Suggest an idea for this project
title: ''
labels: needs prioritization, Requests
assignees: ''

---

**Please describe the problem that needs to be solved by this feature**
A clear and concise description of what the problem is. Ex. I'm always frustrated when [...]

**How important is this feature to you? (Software team will re-prioritize all tickets based on current workload)**
Critical, high priority, medium priority, or low priority.

**Describe the solution you'd like**
A clear and concise description of what you want to happen.

**Describe alternatives you've considered**
A clear and concise description of any alternative solutions or features you've considered.

**Additional context**
Add any other context or screenshots about the feature request here.
